==> zio-aws-amplify_3-5.17.104.9-sources.jar: zio/aws/amplify/model/ListBackendEnvironmentsRequest.scala <==
package zio.aws.amplify.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.amplify.model.primitives.{
  MaxResults,
  NextToken,
  EnvironmentName,
  AppId
}
import scala.jdk.CollectionConverters.*
final case class ListBackendEnvironmentsRequest(
    appId: AppId,
    environmentName: Option[EnvironmentName] = None,
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest = {
    import ListBackendEnvironmentsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
      .builder()
      .appId(AppId.unwrap(appId): java.lang.String)
      .optionallyWith(
        environmentName.map(value =>
          EnvironmentName.unwrap(value): java.lang.String
        )
      )(_.environmentName)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.amplify.model.ListBackendEnvironmentsRequest.ReadOnly =
    zio.aws.amplify.model.ListBackendEnvironmentsRequest.wrap(buildAwsValue())
}
object ListBackendEnvironmentsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplify.model.ListBackendEnvironmentsRequest =
      zio.aws.amplify.model.ListBackendEnvironmentsRequest(
        appId,
        environmentName.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def appId: AppId
    def environmentName: Option[EnvironmentName]
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def getAppId: ZIO[Any, Nothing, AppId] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, AwsError, EnvironmentName] =
      AwsError.unwrapOptionField("environmentName", environmentName)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
  ) extends zio.aws.amplify.model.ListBackendEnvironmentsRequest.ReadOnly {
    override val appId: AppId =
      zio.aws.amplify.model.primitives.AppId(impl.appId())
    override val environmentName: Option[EnvironmentName] = scala
      .Option(impl.environmentName())
      .map(value => zio.aws.amplify.model.primitives.EnvironmentName(value))
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.amplify.model.primitives.NextToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.amplify.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
  ): zio.aws.amplify.model.ListBackendEnvironmentsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplify_3-5.17.175.1-sources.jar: zio/aws/amplify/model/ListBackendEnvironmentsRequest.scala <==
package zio.aws.amplify.model
import zio.prelude.data.Optional
import zio.aws.amplify.model.primitives.{
  MaxResults,
  NextToken,
  EnvironmentName,
  AppId
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListBackendEnvironmentsRequest(
    appId: AppId,
    environmentName: Optional[EnvironmentName] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest = {
    import ListBackendEnvironmentsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
      .builder()
      .appId(AppId.unwrap(appId): java.lang.String)
      .optionallyWith(
        environmentName.map(value =>
          EnvironmentName.unwrap(value): java.lang.String
        )
      )(_.environmentName)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.amplify.model.ListBackendEnvironmentsRequest.ReadOnly =
    zio.aws.amplify.model.ListBackendEnvironmentsRequest.wrap(buildAwsValue())
}
object ListBackendEnvironmentsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplify.model.ListBackendEnvironmentsRequest =
      zio.aws.amplify.model.ListBackendEnvironmentsRequest(
        appId,
        environmentName.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def appId: AppId
    def environmentName: Optional[EnvironmentName]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def getAppId: ZIO[Any, Nothing, AppId] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, AwsError, EnvironmentName] =
      AwsError.unwrapOptionField("environmentName", environmentName)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
  ) extends zio.aws.amplify.model.ListBackendEnvironmentsRequest.ReadOnly {
    override val appId: AppId =
      zio.aws.amplify.model.primitives.AppId(impl.appId())
    override val environmentName: Optional[EnvironmentName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.environmentName())
        .map(value => zio.aws.amplify.model.primitives.EnvironmentName(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.amplify.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.amplify.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplify.model.ListBackendEnvironmentsRequest
  ): zio.aws.amplify.model.ListBackendEnvironmentsRequest.ReadOnly =
    new Wrapper(impl)
}
